@@ -8,24 +8,6 @@ def clear_screen():
 
 
 if __name__ == '__main__':
-    while True:
-        session_token = input('Please enter your session token: ')
-        #session_token = "ey"
-        conversation_id = input(
-           'Please enter your conversation id (if you want to continue old chat): '
-        )
-        #conversation_id = ""
-        proxy = input('Please enter your proxy if you have: eg: http://127.0.0.1:8080')
-        #proxy = "http://127.0.0.1:1090"
-        driver_path = input('Please enter your chromedriver path if you have: eg: D:\\chromedriver.exe')
-        #driver_path = "chromedriver.exe"
-        chat = ChatGPT(session_token, conversation_id,proxy=proxy,driver_path=driver_path)
-        break
-
-    clear_screen()
-    print(
-        'Conversation started. Type "reset" to reset the conversation.Type "back some words" to loop the conversation. Type "quit" to quit.\n'
-    )
     words = [
         {
             "content":r'Now you are going to pretend to be a math teacher called "nothing" to help me with my math',
@@ -39,6 +21,26 @@ if __name__ == '__main__':
     '''
     An example of initializing the vocabulary format, the vocabulary content is not representative
     '''
+    while True:
+        session_token = input('Please enter your session token: ')
+        #session_token = "ey"
+        conversation_id = input(
+           'Please enter your conversation id (if you want to continue old chat): '
+        )
+        #conversation_id = ""
+        proxy = input('Please enter your proxy if you have: eg: http://127.0.0.1:8080')
+        #proxy = "http://127.0.0.1:1090"
+        driver_path = input('Please enter your chromedriver path if you have: eg: D:\\chromedriver.exe')
+        #driver_path = "chromedriver.exe"
+        
+        chat = ChatGPT(session_token, conversation_id,proxy=proxy,driver_path=driver_path,personality_definition = words)
+        break
+
+    clear_screen()
+    print(
+        'Conversation started. Type "reset" to reset the conversation.Type "back some words" to loop the conversation. Type "quit" to quit.\n'
+    )
+    
     
     while True:
         prompt = input('\nYou: ')
